package com.yidian.shenghuoquan.bpush.base

import android.content.Context
import com.umeng.commonsdk.UMConfigure
import com.yidian.shenghuoquan.bpush.constant.BrandConstant
import com.yidian.shenghuoquan.bpush.constant.Constant
import com.yidian.shenghuoquan.bpush.push.PushSdkManager
import com.yidian.shenghuoquan.bpush.push.huaweipush.HuaWeiPushPolicy
import com.yidian.shenghuoquan.bpush.push.mipush.MiPushPolicy
import com.yidian.shenghuoquan.bpush.push.oppopush.OppoPushPolicy
import com.yidian.shenghuoquan.bpush.push.umengpush.helper.UmengPushPolicy
import com.yidian.shenghuoquan.bpush.push.vivopush.ViVoPushPolicy
import com.yidian.shenghuoquan.bpush.utils.SystemUtil
import timber.log.Timber
import java.util.*

class BPush {
  private lateinit var pushSdkManager: PushSdkManager
  public fun init(context: Context) {
    // 开关
    UMConfigure.setLogEnabled(true)
    //预初始化
    UmengPushPolicy.preInit(context)
    //正式初始化
    if (UmengPushPolicy.isMainProcess(context)) {
      //建议在线程中执行初始化
      Thread { UmengPushPolicy.init(context) }.start()
    }
    initPlatformPush()
  }

  private fun initPlatformPush() {
    if (this::pushSdkManager.isInitialized && pushSdkManager.pushStatus() == Constant.pushConnected) {
      Timber.tag("BPush").i("push sdk has initiallized")
      return
    }
    Timber.tag("BPush").i("brand is ${SystemUtil.getDeviceBrand()}")
    when(SystemUtil.getDeviceBrand()) {
      BrandConstant.HUAWEI -> {
        pushSdkManager = PushSdkManager(HuaWeiPushPolicy())
      }
      BrandConstant.OPPO -> {
        pushSdkManager = PushSdkManager(OppoPushPolicy())
      }
      BrandConstant.VIVO -> {
        pushSdkManager = PushSdkManager(ViVoPushPolicy())
      }
      BrandConstant.XIAOMI -> {
        pushSdkManager = PushSdkManager(MiPushPolicy())
      }
    }
    pushSdkManager.initSpecealSdk()
  }

}
